@@ -1,7 +1,8 @@
 import itertools
 import json
 from collections import defaultdict
-from collections.abc import Sequence
+from collections.abc import Iterator, Sequence
+from dataclasses import dataclass
 from typing import Any, Literal, cast, overload
 
 from cognite.client import CogniteClient
@@ -18,7 +19,13 @@ from .builder import QueryBuilder
 from .constants import AGGREGATION_LIMIT, IN_FILTER_CHUNK_SIZE, SEARCH_LIMIT, SelectedProperties
 from .executor import chunker
 from .processing import QueryUnpacker
-from .step import QueryBuildStepFactory
+from .step import QueryBuildStepFactory, QueryResultStepList
+
+
+@dataclass
+class Page:
+    items: list[dict[str, Any]]
+    cursor: str | None
 
 
 class QueryExecutor:
@@ -54,6 +61,7 @@ class QueryExecutor:
         filter: filters.Filter | None = None,
         search_properties: str | SequenceNotStr[str] | None = None,
         sort: Sequence[dm.InstanceSort] | dm.InstanceSort | None = None,
+        operator: Literal["AND", "OR"] | None = None,
         limit: int | None = None,
         instance_types: list[Literal["node", "edge"]] | None = None,
     ) -> list[dict[str, Any]]:
@@ -70,6 +78,11 @@ class QueryExecutor:
             filter: The filter to apply ahead of the search.
             search_properties: The properties to search. If None, all text properties are searched.
             sort: The sort order of the results.
+            operator: Controls how multiple search terms are combined when matching documents.
+                OR (default): A document matches if it contains any of the query terms in the searchable fields.
+                    This typically returns more results but with lower precision.
+                AND: A document matches only if it contains all of the query terms across the searchable fields.
+                    This typically returns fewer results but with higher relevance.
             limit: The maximum number of results to return. Max 1000.
             instance_types: The instance types to search. If None, defaults to the view's supported types.
 
@@ -82,7 +95,9 @@ class QueryExecutor:
 
         """
         filter = self._equals_none_to_not_exists(filter)
-        return self._execute_search(view, properties, query, filter, search_properties, sort, limit, instance_types)
+        return self._execute_search(
+            view, properties, query, filter, search_properties, sort, limit, operator, instance_types
+        )
 
     def _execute_search(
         self,
@@ -93,8 +108,12 @@ class QueryExecutor:
         search_properties: str | SequenceNotStr[str] | None = None,
         sort: Sequence[dm.InstanceSort] | dm.InstanceSort | None = None,
         limit: int | None = None,
+        operator: Literal["AND", "OR"] | None = None,
         instance_types: list[Literal["node", "edge"]] | None = None,
     ) -> list[dict[str, Any]]:
+        # The SDK requires the operator to be set to AND or OR, however we want to
+        # just use the default if not specified as this is expected to change in the future.
+        operator_arg: dict[str, Any] = {"operator": operator} if operator is not None else {}
         view = self._get_view(view_id)
         flatten_props, are_flat_properties = self._as_property_list(properties, "list") if properties else (None, False)
         if properties is None or are_flat_properties:
@@ -112,6 +131,7 @@ class QueryExecutor:
                     filter=filter,
                     limit=limit or SEARCH_LIMIT,
                     sort=sort,
+                    **operator_arg,
                 )
                 all_results.extend(
                     self._prepare_list_result(search_instance_result, set(flatten_props) if flatten_props else None)
@@ -119,7 +139,7 @@ class QueryExecutor:
             return all_results
         elif view.used_for == "edge":
             raise ValueError("Nested properties are not supported for edges")
-        search_result = self._client.data_modeling.instances.search(  # type: ignore[call-overload]
+        search_result = self._client.data_modeling.instances.search(  # type: ignore[call-overload, misc]
             view_id,
             query,
             instance_type="node",
@@ -127,6 +147,7 @@ class QueryExecutor:
             filter=filter,
             limit=limit or SEARCH_LIMIT,
             sort=sort,
+            **operator_arg,
         )
         # Lookup nested properties:
         order_by_node_ids = {node.as_id(): no for no, node in enumerate(search_result)}
@@ -315,7 +336,7 @@ class QueryExecutor:
             for prop in factory.reverse_properties.values()
             if isinstance(prop.through.source, dm.ViewId)
         }
-        builder.append(factory.root(filter, limit=limit))
+        builder.append(factory.root(filter, limit=limit, sort=self._as_sort_list(sort)))
         for connection_id, connection in factory.connection_properties.items():
             builder.extend(factory.from_connection(connection_id, connection, reverse_views))
         executor = builder.build()
@@ -340,6 +361,47 @@ class QueryExecutor:
                 output.append(item)  # type: ignore[arg-type]
         return output
 
+    def _execute_iterate(
+        self,
+        view_id: dm.ViewId,
+        properties: list[str],
+        filter: filters.Filter | None = None,
+        sort: Sequence[dm.InstanceSort] | dm.InstanceSort | None = None,
+        cursor: str | None = None,
+        chunk_size: int | None = None,
+    ) -> Iterator[Page]:
+        view = self._get_view(view_id)
+        builder = QueryBuilder()
+        factory = QueryBuildStepFactory(
+            # MyPy complains about invariance.
+            builder.create_name,
+            view=view,
+            user_selected_properties=properties,  # type: ignore[arg-type]
+            unpack_edges=self._unpack_edges,
+        )
+        builder.append(
+            factory.root(filter, limit=None, sort=self._as_sort_list(sort), max_retrieve_batch_limit=chunk_size)
+        )
+
+        executor = builder.build()
+        init_cursors: dict[str, str | None] | None = None
+        if cursor is not None:
+            init_cursors = {factory.root_name: cursor}
+        step: QueryResultStepList
+        for step in executor.iterate(self._client, remove_not_connected=False, init_cursors=init_cursors):
+            items = QueryUnpacker(
+                step, edges=self._unpack_edges, as_data_record=False, edge_type_key="type", node_type_key="type"
+            ).unpack()
+            yield Page(items=items, cursor=step._cursors.get(factory.root_name))
+
+    @staticmethod
+    def _as_sort_list(sort: dm.InstanceSort | Sequence[dm.InstanceSort] | None) -> list[dm.InstanceSort] | None:
+        if sort is None:
+            return None
+        if isinstance(sort, dm.InstanceSort):
+            return [sort]
+        return list(sort)
+
     def _execute_aggregation(
         self,
         view_id: dm.ViewId,
@@ -477,6 +539,32 @@ class QueryExecutor:
             }
         return dict(output)
 
+    def iterate(
+        self,
+        view: dm.ViewId,
+        properties: list[str],
+        filter: filters.Filter | None = None,
+        sort: Sequence[dm.InstanceSort] | dm.InstanceSort | None = None,
+        initial_cursor: str | None = None,
+        chunk_size: int | None = None,
+    ) -> Iterator[Page]:
+        """Iterate over nodes in a view.
+
+        Args:
+            view: The view in which the nodes have properties.
+            properties: The properties to include in the result.
+            filter: The filter to apply ahead of the list operation.
+            sort: The sort order of the results.
+            initial_cursor: The cursor to start from. If None, starts from the beginning.
+            chunk_size: The number of results to include in each page. If None, defaults to 1000.
+
+        Returns:
+            Page: The page of results.
+
+        """
+        filter = self._equals_none_to_not_exists(filter)
+        yield from self._execute_iterate(view, properties, filter, sort, initial_cursor, chunk_size)
+
     def list(
         self,
         view: dm.ViewId,
