@@ -136,6 +136,9 @@ class QueryUnpacker:
             to 'edge_type'.
         node_type_key: The key to use for the node type. Default is "type". In pygen generated SDKs, this is set
             to 'node_type'.
+        edge_connections: How to represent the connections of edges. If "list", the connections are represented
+            as a list of dictionaries. If "object", the connections are represented as a dictionary with the
+            connection property as the key and the target node as the value. Default is "list".
 
     Example:
         Unpacking query steps including edges:
@@ -195,19 +198,23 @@ class QueryUnpacker:
         as_data_record: bool = True,
         edge_type_key: str = "edge_type",
         node_type_key: str = "node_type",
+        edge_connections: Literal["list", "object"] = "list",
     ) -> None:
         self._steps = steps
         self._edges = edges
         self._as_data_record = as_data_record
         self._edge_type_key = edge_type_key
         self._node_type_key = node_type_key
+        self._edge_connections = edge_connections
 
     def unpack(self) -> list[dict[str, Any]]:
+        if not self._steps:
+            return []
         # The unpacked nodes/edges are stored in the dictionary below
         # dict[Step Name, list[Connection Property, dict[Source Node ID, list[Target Node]]]]
         # This is used for each step, to look up the connected nodes/edges.
         nodes_by_step_name: dict[str, list[tuple[str, dict[dm.NodeId, list[dict[str, Any]]]]]] = defaultdict(list)
-        fist_step = self._steps[0]
+        first_step = self._steps[0]
         output: list[dict[str, Any]] = []
         # The steps are organized in a tree structure, where each step has a reference to a previous step.
         # The unpacking is done in reverse order, starting with the last step, i.e., the leaf steps. This
@@ -220,7 +227,7 @@ class QueryUnpacker:
             else:
                 raise TypeError("Unexpected step")
 
-            if step is fist_step:
+            if step is first_step:
                 output = [item for items in unpacked.values() for item in items]
             elif (connection_property := step.connection_property) and (step.from_ is not None):
                 nodes_by_step_name[step.from_].append((connection_property.property, unpacked))
@@ -235,7 +242,7 @@ class QueryUnpacker:
     @classmethod
     def flatten_dump(
         cls,
-        node: dm.Node | dm.Edge,
+        instance: dm.Node | dm.Edge,
         selected_properties: set[str] | None,
         direct_property: str | None = None,
         as_data_record: bool = False,
@@ -244,7 +251,7 @@ class QueryUnpacker:
         """Dumps the node/edge into a flat dictionary.
 
         Args:
-            node: The node or edge to dump.
+            instance: The node or edge to dump.
             selected_properties: The properties to include in the dump. If None, all properties are included.
             direct_property: Assumed to be the property ID of a direct relation. If present, the value
                 of this property will be converted to a NodeId or a list of NodeIds. The motivation for this is
@@ -256,8 +263,10 @@ class QueryUnpacker:
             A dictionary with the properties of the node or edge
 
         """
-        dumped = node.dump()
+        dumped = instance.dump()
         dumped_properties = dumped.pop("properties", {})
+        # Remove instanceType if present. We already have the instance type context.
+        dumped.pop("instanceType", None)
         if "type" in dumped:
             dumped[type_key] = dumped.pop("type")
 
@@ -355,35 +364,58 @@ class QueryUnpacker:
     ) -> dict[dm.NodeId, list[dict[str, Any]]]:
         step_properties = set(step.selected_properties or []) or None
         unpacked_by_source: dict[dm.NodeId, list[dict[str, Any]]] = defaultdict(list)
+        is_leaf_step = len(connections) == 0
         for edge in step.edge_results:
-            start_node = dm.NodeId.load(edge.start_node.dump())  # type: ignore[arg-type]
-            end_node = dm.NodeId.load(edge.end_node.dump())  # type: ignore[arg-type]
+            start_node, end_node = dm.NodeId.load(edge.start_node.dump()), dm.NodeId.load(edge.end_node.dump())  # type: ignore[arg-type]
             if edge_expression.direction == "outwards":
-                source_node = start_node
-                target_node = end_node
+                source_node, target_node = start_node, end_node
             else:
-                source_node = end_node
-                target_node = start_node
+                source_node, target_node = end_node, start_node
             # step.view_id means that the edge has properties
+            dumped_edge: dict[str, Any]
             if self._edges == "include" or step.view_id:
-                dumped = self.flatten_dump(
+                dumped_edge = self.flatten_dump(
                     edge, step_properties, as_data_record=self._as_data_record, type_key=self._edge_type_key
                 )
-                for connection_property, node_targets_by_source in connections:
-                    if target_node in node_targets_by_source:
-                        dumped[connection_property] = node_targets_by_source[target_node]
-
-                unpacked_by_source[source_node].append(dumped)
+                self._append_connections(dumped_edge, connections, target_node, edge.as_id())
+                dumped = [dumped_edge]
             elif self._edges == "identifier":
-                dumped = edge.as_id().dump(include_instance_type=False)
-                unpacked_by_source[source_node].append(dumped)
+                dumped_edge = edge.as_id().dump(include_instance_type=False)
+                self._append_connections(dumped_edge, connections, target_node, edge.as_id())
+                dumped = [dumped_edge]
+            elif self._edges == "skip" and is_leaf_step:
+                dumped = [target_node.dump(include_instance_type=False)]
             elif self._edges == "skip":
+                # Skipping the edge, instead adding the target node to the source node
+                # such that the target node(s) can be connected to the source node.
                 for _, node_targets_by_source in connections:
                     if target_node in node_targets_by_source:
-                        # Skipping the edge, instead adding the target node to the source node
-                        # such that the target node(s) can be connected to the source node.
                         unpacked_by_source[source_node].extend(node_targets_by_source[target_node])
+                continue
             else:
                 raise ValueError(f"Unexpected value for edges: {self._edges}")
-
+            unpacked_by_source[source_node].extend(dumped)
         return unpacked_by_source
+
+    def _append_connections(
+        self,
+        dumped_edge: dict[str, Any],
+        connections: list[tuple[str, dict[dm.NodeId, list[dict[str, Any]]]]],
+        target_node: dm.NodeId,
+        edge_id: dm.EdgeId,
+    ) -> None:
+        for connection_property, node_targets_by_source in connections:
+            if dumped_target_node := node_targets_by_source.get(target_node):
+                if self._edge_connections == "list":
+                    dumped_edge[connection_property] = dumped_target_node
+                elif self._edge_connections == "object":
+                    if len(dumped_target_node) != 1:
+                        raise ValueError(
+                            f"Expected exactly one target node for connection property '{connection_property}'"
+                            f" for edge {edge_id}. Found: {len(dumped_target_node)}"
+                        )
+                    dumped_edge[connection_property] = dumped_target_node[0]
+                else:
+                    raise ValueError(
+                        f"Unexpected value for edge_connections: {self._edge_connections}. Expected 'list' or 'object'."
+                    )
