@@ -4,11 +4,12 @@ import pytest
 from cognite.client import CogniteClient
 from cognite.client import data_modeling as dm
 from cognite.client.data_classes import filters
+from cognite.client.data_classes.data_modeling import InstanceSort
 from omni import OmniClient
 from omni import data_classes as dc
 
 from cognite.pygen._query.constants import SelectedProperties
-from cognite.pygen._query.interface import QueryExecutor
+from cognite.pygen._query.interface import Page, QueryExecutor
 
 
 def test_query_reverse_direct_relation(cognite_client: CogniteClient, omni_views: dict[str, dm.View]) -> None:
@@ -84,6 +85,7 @@ def test_query_direct_relation(cognite_client: CogniteClient, omni_views: dict[s
 
 def test_query_edge_outwards(cognite_client: CogniteClient, omni_views: dict[str, dm.View]) -> None:
     item_a = omni_views["ConnectionItemA"]
+    view_A_id = item_a.as_id()
     item_b = omni_views["ConnectionItemB"]
     executor = QueryExecutor(cognite_client, views=[item_a, item_b], unpack_edges="include")
     properties: list[str | dict[str, Any]] = [
@@ -92,7 +94,12 @@ def test_query_edge_outwards(cognite_client: CogniteClient, omni_views: dict[str
         {"outwards": [{"node": ["name", "externalId"]}, "type"]},
     ]
     flatten_props = {"name", "outwards", "externalId"}
-    result = executor.list(item_a.as_id(), properties, limit=5)
+    result = executor.list(
+        view_A_id,
+        properties,
+        sort=InstanceSort(view_A_id.as_property_ref("name"), direction="descending", nulls_first=True),
+        limit=5,
+    )
     assert isinstance(result, list)
     assert len(result) > 0
     ill_formed_items = [item for item in result if not (set(item.keys()) <= flatten_props)]
@@ -106,6 +113,8 @@ def test_query_edge_outwards(cognite_client: CogniteClient, omni_views: dict[str
     ]
     assert not ill_formed_subitems, f"Subitems with unexpected properties: {ill_formed_subitems}"
 
+    assert result == sorted(result, key=lambda x: (int("name" not in x), x.get("name", "")), reverse=True)
+
 
 def test_query_edge_outwards_skip_edge(cognite_client: CogniteClient, omni_views: dict[str, dm.View]) -> None:
     item_a = omni_views["ConnectionItemA"]
@@ -265,6 +274,28 @@ def test_search_nested_properties(cognite_client: CogniteClient, omni_views: dic
     assert not ill_formed_subitems, f"Subitems with unexpected properties: {ill_formed_subitems}"
 
 
+def test_search_AND(cognite_client: CogniteClient, omni_client: OmniClient, omni_views: dict[str, dm.View]) -> None:
+    items = omni_client.primitive_required.list(limit=1)
+    assert len(items) > 0
+    item = items[0]
+    words = item.text.split(" ")
+    # The text property should be at least 3 words. (It is generated lorem ipsum text.)
+    assert len(words) > 2
+
+    view = omni_views["PrimitiveRequired"]
+    executor = QueryExecutor(cognite_client, views=[view], unpack_edges="include")
+    selected_properties: list[str | dict[str, Any]] = ["text", "boolean", "externalId"]
+    result = executor.search(view.as_id(), selected_properties, query=" ".join(words), operator="AND", limit=5)
+
+    assert isinstance(result, list)
+    assert len(result) > 0
+    properties_set = set(selected_properties)
+    ill_formed_items = [item for item in result if not (set(item.keys()) <= properties_set)]
+    assert not ill_formed_items, f"Items with unexpected properties: {ill_formed_items}"
+    # As we are searching with AND, we expect only one result
+    assert len(result) == 1
+
+
 def test_query_list_root_nodes(cognite_client: CogniteClient) -> None:
     executor = QueryExecutor(cognite_client, unpack_edges="include")
     view_id = dm.ViewId("cdf_cdm", "CogniteAsset", "v1")
@@ -335,3 +366,46 @@ def test_query_search_edges(
     assert isinstance(result, list)
     assert len(result) > 0
     assert all(all(prop in item for prop in selected_properties) for item in result)
+
+
+class TestQueryExecutorIterate:
+    def test_iterate_from_last_page(self, cognite_client: CogniteClient, omni_views: dict[str, dm.View]) -> None:
+        view = omni_views["PrimitiveRequired"]
+        executor = QueryExecutor(cognite_client, views=[view], unpack_edges="skip")
+        properties = ["externalId", "text", "boolean", "externalId"]
+        first_page = next(iter(executor.iterate(view.as_id(), properties, chunk_size=2)))
+        assert len(first_page.items) == 2
+        incorrect_items = [item for item in first_page.items if not (set(item.keys()) <= set(properties))]
+        assert not incorrect_items, f"Items with unexpected properties: {incorrect_items}"
+
+        second_page = next(
+            iter(executor.iterate(view.as_id(), properties, chunk_size=2, initial_cursor=first_page.cursor))
+        )
+        assert len(second_page.items) == 2
+        incorrect_items = [item for item in second_page.items if not (set(item.keys()) <= set(properties))]
+        assert not incorrect_items, f"Items with unexpected properties: {incorrect_items}"
+
+        assert first_page.items != second_page.items
+
+    def test_iterate_two_pages(self, cognite_client: CogniteClient, omni_views: dict[str, dm.View]) -> None:
+        view = omni_views["PrimitiveRequired"]
+        executor = QueryExecutor(cognite_client, views=[view], unpack_edges="skip")
+        properties = ["externalId", "text", "boolean", "externalId"]
+        first_page: Page | None = None
+        second_page: Page | None = None
+        for page in executor.iterate(view.as_id(), properties, chunk_size=2):
+            if first_page is None:
+                first_page = page
+            elif second_page is None:
+                second_page = page
+                break
+
+        assert first_page is not None, "First page is None"
+        assert second_page is not None, "Second page is None"
+        assert len(first_page.items) == 2
+        assert len(second_page.items) == 2
+        assert first_page.items != second_page.items
+        incorrect_items = [
+            item for item in first_page.items + second_page.items if not (set(item.keys()) <= set(properties))
+        ]
+        assert not incorrect_items, f"Items with unexpected properties: {incorrect_items}"
